@@ -13,7 +13,6 @@
 ##################################################
 
 import semantyk
-from semantyk.namespace import SMTK
 
-def test_namespace():
-    print(SMTK)
\ No newline at end of file
+def test_import():
+    print(semantyk)
\ No newline at end of file
